*************
API Reference
*************

Flattening Module
=================

.. automodule:: spoonbill.flatten

.. autoclass:: TableFlattenConfig

.. autoclass:: FlattenOptions

.. autoclass:: Flattener

CLI Module
==========

.. automodule:: spoonbill.cli

.. autoclass:: CommaSeparated

Spec Module
===========

.. automodule:: spoonbill.spec

.. autoclass:: Column

.. autoclass:: Table

Stats Module
============

.. automodule:: spoonbill.stats

.. autoclass:: DataPreprocessor

Writers Module
==============

CSV
---

.. automodule:: spoonbill.writers.csv

.. autoclass:: CSVWriter

XLSX
----

.. automodule:: spoonbill.writers.xlsx

.. autoclass:: XlsxWriter
